<html xmlns="http://www.w3.org/1999/xhtml">
  <head>
    <title>Example layout</title>
    
    <!-- meta -->
    <meta name="generator" content="Emacs" />
    <meta name="description" content="This is an example layout." />
    <meta name="keywords" content="example, layout, xss." />

    <link rel="xss" type="text/xss" href="example.xss" />
    
    <style type="text/css"><!-- @import url(example.css); --></style>
    <link rel="kukit" type="text/kss" href="example.kss" />
    <script type="text/javascript" src="example.js">
    </script>
  </head>
  <body>
    <div id="content">
      This is the content area.
    </div>
    <img src="example.png" />
  </body>
</html>
